==> scala-k8s-objects_2.12-0.18.0-sources.jar: io/k8s/api/core/v1/HostAlias.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file. */
final case class HostAlias(
  ip : String,
  hostnames : Option[Seq[String]] = None
) {

  /** Returns a new data with ip set to new value */
  def withIp(value: String) : HostAlias = copy(ip = value)
  /** transforms ip to result of function */
  def mapIp(f: String => String) : HostAlias = copy(ip = f(ip))

  /** Returns a new data with hostnames set to new value */
  def withHostnames(value: Seq[String]) : HostAlias = copy(hostnames = Some(value))
  /** Appends new values to hostnames */
  def addHostnames(newValues: String*) : HostAlias = copy(hostnames = Some(hostnames.fold(newValues)(_ ++ newValues)))
  /** if hostnames has a value, transforms to the result of function*/
  def mapHostnames(f: Seq[String] => Seq[String]) : HostAlias = copy(hostnames = hostnames.map(f))
}

object HostAlias {

    implicit val encoder : Encoder[io.k8s.api.core.v1.HostAlias] = new Encoder[io.k8s.api.core.v1.HostAlias] {
        def apply[T : Builder](o: io.k8s.api.core.v1.HostAlias) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("ip", o.ip)
            .write("hostnames", o.hostnames)
            .build
        }
    }

    implicit val decoder: Decoder[HostAlias] = new Decoder[HostAlias] {
      def apply[T : Reader](t: T): Either[String, HostAlias] = for {
          obj <- ObjectReader(t)
          ip <- obj.read[String]("ip")
          hostnames <- obj.readOpt[Seq[String]]("hostnames")
      } yield HostAlias (
          ip = ip,
          hostnames = hostnames
        )
    }
}

==> scala-k8s-objects_3-0.5.1-sources.jar: io/k8s/api/core/v1/HostAlias.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file. */
final case class HostAlias(
  hostnames : Option[Seq[String]] = None,
  ip : Option[String] = None
) {

  /** Returns a new data with hostnames set to new value */
  def withHostnames(value: Seq[String]) : HostAlias = copy(hostnames = Some(value))
  /** Appends new values to hostnames */
  def addHostnames(newValues: String*) : HostAlias = copy(hostnames = Some(hostnames.fold(newValues)(_ ++ newValues)))
  /** if hostnames has a value, transforms to the result of function*/
  def mapHostnames(f: Seq[String] => Seq[String]) : HostAlias = copy(hostnames = hostnames.map(f))

  /** Returns a new data with ip set to new value */
  def withIp(value: String) : HostAlias = copy(ip = Some(value))
  /** if ip has a value, transforms to the result of function*/
  def mapIp(f: String => String) : HostAlias = copy(ip = ip.map(f))
}

object HostAlias {

    implicit val encoder : Encoder[io.k8s.api.core.v1.HostAlias] = new Encoder[io.k8s.api.core.v1.HostAlias] {
        def apply[T : Builder](o: io.k8s.api.core.v1.HostAlias) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("hostnames", o.hostnames)
            .write("ip", o.ip)
            .build
        }
    }

    implicit val decoder: Decoder[HostAlias] = new Decoder[HostAlias] {
      def apply[T : Reader](t: T): Either[String, HostAlias] = for {
          obj <- ObjectReader(t)
          hostnames <- obj.readOpt[Seq[String]]("hostnames")
          ip <- obj.readOpt[String]("ip")
      } yield HostAlias (
          hostnames = hostnames,
          ip = ip
        )
    }
}
